/MIMEco : Metabolic Interaction Modeling in Ecosystems
=======================================================

MIMEco is python package that explores communities metabolic interactions using multi-objective linear programming on GEnome-scale Metabolic models (GEMs). 
This tool automates the inference of interaction type, interaction score and exchanged metablites between two models in a given condition.

.. image:: mimeco/resources/MIMEco_logo.png
  :width: 500
  :alt: MIMEco logo

Documentation
~~~~~~~~~~~~~

For detailed documentation, please go to `readthedocs : mimeco <https://mimeco.readthedocs.io/en/latest/>`_

Installation
~~~~~~~~~~~~~

<Under developpment>
This tool is destined to be available using pip.

Dependancies
~~~~~~~~~~~~~

To use MIMEco, you will need to download a solver, preferably CPLEX or gurobi. Both are free for academics.

<Dependancies that are in pip so juste to put in setup.py : mocbapy, pickle, warnings, pandas, sklearn, math>


Credits and License
~~~~~~~~~~~~~~~~~~~

<TODO>
